/*
    *
    * This file is a part of CoreImage.
    * An image viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 2 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#ifndef COREIMAGE_H
#define COREIMAGE_H

#include <QWidget>
#include <QImage>
#include <QLabel>

#include <cprime/settingsmanage.h>


class QListWidgetItem;
class QSpacerItem;
class QTimer;
class QScrollBar;

namespace Ui {
	class coreimage;
}

class coreimage : public QWidget {

	Q_OBJECT

public:
	explicit coreimage(QWidget *parent = nullptr);
	~coreimage();

	void sendFiles(const QStringList &paths);
	bool loadFile(const QString &);
	QString workFilePath;


private slots:
	void on_cSave_clicked();
    void on_cSaveAs_clicked();
	void on_cTrashIt_clicked();
	void on_containingFolder_clicked();
	void on_openInEditor_clicked();
	void on_slideShow_clicked(bool checked);
	void on_pinIt_clicked();
	void previousItem();
	void nextItem();
	void showProperties();
    void on_openmetadataApp_clicked();
    void on_shearIt_clicked();
    void openFileDialog();
    void on_rotate_clicked();
    void showSideView();

protected:
	void closeEvent(QCloseEvent *event);

private:
	Ui::coreimage  *ui;
    settingsManage *sm = settingsManage::initialize();
	bool            sideView, touch, slideShow;
    int             sideViewSize;
    QSize           sideViewIconSize, toolBarIconSize;
	QTimer         *slideShowTimer;
	QStringList     imagesList;

	QLabel *zoomLbl;

	static QStringList openFilters;
	static QStringList saveFilters;

	void getImages(const QString &path);
	void setImage(const QImage &newImage);
	void shortcuts();
	void startMode();
	void loadSettings();
	void startSetup();
	void getImageFilters();
};

#endif // COREIMAGE_H
